import type { ResideoPlatform } from '../platform.js';
import type { API, HAP, Logging, PlatformAccessory } from 'homebridge';
import type { ResideoPlatformConfig, resideoDevice, location, devicesConfig } from '../settings.js';
export declare abstract class deviceBase {
    protected readonly platform: ResideoPlatform;
    protected accessory: PlatformAccessory;
    protected location: location;
    protected device: resideoDevice & devicesConfig;
    readonly api: API;
    readonly log: Logging;
    readonly config: ResideoPlatformConfig;
    protected readonly hap: HAP;
    protected deviceLogging: string;
    protected deviceUpdateRate: number;
    protected deviceRefreshRate: number;
    protected deviceMaxRetries: number;
    protected deviceDelayBetweenRetries: number;
    constructor(platform: ResideoPlatform, accessory: PlatformAccessory, location: location, device: resideoDevice & devicesConfig);
    getDeviceLogSettings(device: resideoDevice & devicesConfig): Promise<void>;
    getDeviceRefreshRateSettings(device: resideoDevice & devicesConfig): Promise<void>;
    getDeviceRetry(device: resideoDevice & devicesConfig): Promise<void>;
    getDeviceConfigSettings(device: resideoDevice & devicesConfig): Promise<void>;
    getDeviceContext(accessory: PlatformAccessory, device: resideoDevice & devicesConfig): Promise<void>;
    statusCode(statusCode: number, action: string): Promise<void>;
    resideoAPIError(e: any, action: string): Promise<void>;
    /**
     * Logging for Device
     */
    infoLog(...log: any[]): void;
    successLog(...log: any[]): void;
    debugSuccessLog(...log: any[]): void;
    warnLog(...log: any[]): void;
    debugWarnLog(...log: any[]): void;
    errorLog(...log: any[]): void;
    debugErrorLog(...log: any[]): void;
    debugLog(...log: any[]): void;
    enablingDeviceLogging(): boolean;
}
//# sourceMappingURL=device.d.ts.map