import { Subject } from 'rxjs';
import { deviceBase } from './device.js';
import type { ResideoPlatform } from '../platform.js';
import type { PlatformAccessory, CharacteristicValue } from 'homebridge';
import type { devicesConfig, location, resideoDevice, sensorAccessory, T9groups } from '../settings.js';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export declare class RoomSensors extends deviceBase {
    readonly platform: ResideoPlatform;
    sensorAccessory: sensorAccessory;
    readonly group: T9groups;
    private Battery;
    private OccupancySensor?;
    private HumiditySensor?;
    private TemperatureSensor?;
    TemperatureDisplayUnits: CharacteristicValue;
    accessoryId: number;
    roomId: number;
    SensorUpdateInProgress: boolean;
    doSensorUpdate: Subject<void>;
    constructor(platform: ResideoPlatform, accessory: PlatformAccessory, location: location, device: resideoDevice & devicesConfig, sensorAccessory: sensorAccessory, group: T9groups);
    /**
     * Parse the device status from the Resideo api
     */
    parseStatus(device: resideoDevice & devicesConfig, sensorAccessory: sensorAccessory): Promise<void>;
    /**
     * Asks the Resideo Home API for the latest device information
     */
    refreshStatus(): Promise<void>;
    /**
     * Updates the status for each of the HomeKit Characteristics
     */
    updateHomeKitCharacteristics(): Promise<void>;
    apiError(e: any): Promise<void>;
}
//# sourceMappingURL=roomsensors.d.ts.map