import { Subject } from 'rxjs';
import { deviceBase } from './device.js';
import type { ResideoPlatform } from '../platform.js';
import type { PlatformAccessory, CharacteristicValue } from 'homebridge';
import type { devicesConfig, resideoDevice, sensorAccessory, T9groups, location } from '../settings.js';
/**
 * Platform Accessory
 * An instance of this class is created for each accessory your platform registers
 * Each accessory may expose multiple services of different service types.
 */
export declare class RoomSensorThermostat extends deviceBase {
    readonly platform: ResideoPlatform;
    sensorAccessory: sensorAccessory;
    readonly group: T9groups;
    private Thermostat;
    private HumiditySensor?;
    roomPriorityStatus: any;
    thermostatUpdateInProgress: boolean;
    doThermostatUpdate: Subject<void>;
    roomUpdateInProgress: boolean;
    doRoomUpdate: Subject<void>;
    fanUpdateInProgress: boolean;
    doFanUpdate: Subject<void>;
    constructor(platform: ResideoPlatform, accessory: PlatformAccessory, location: location, device: resideoDevice & devicesConfig, sensorAccessory: sensorAccessory, group: T9groups);
    /**
     * Parse the device status from the Resideo api
     */
    parseStatus(device: resideoDevice & devicesConfig, sensorAccessory?: any): Promise<void>;
    /**
     * Asks the Resideo Home API for the latest device information
     */
    refreshStatus(): Promise<void>;
    /**
     * Asks the Resideo Home API for the latest device information
     */
    refreshSensorStatus(): Promise<void>;
    refreshRoomPriority(): Promise<void>;
    /**
     * Pushes the requested changes for Room Priority to the Resideo API
     */
    pushRoomChanges(): Promise<void>;
    /**
     * Pushes the requested changes to the Resideo API
     */
    pushChanges(): Promise<void>;
    ResideoMode(): Promise<string>;
    /**
     * Updates the status for each of the HomeKit Characteristics
     */
    updateHomeKitCharacteristics(): Promise<void>;
    apiError(e: any): Promise<void>;
    setTargetHeatingCoolingState(value: CharacteristicValue): Promise<void>;
    setHeatingThresholdTemperature(value: CharacteristicValue): Promise<void>;
    setCoolingThresholdTemperature(value: CharacteristicValue): Promise<void>;
    setTargetTemperature(value: CharacteristicValue): Promise<void>;
    setTemperatureDisplayUnits(value: CharacteristicValue): Promise<void>;
}
//# sourceMappingURL=roomsensorthermostats.d.ts.map