import type { AxiosInstance } from 'axios';
import type { ResideoPlatformConfig, T9groups, accessoryAttribute, devicesConfig, location, locations, resideoDevice, sensorAccessory } from './settings.js';
import type { API, DynamicPlatformPlugin, HAP, Logging, PlatformAccessory } from 'homebridge';
/**
 * HomebridgePlatform
 * This class is the main constructor for your plugin, this is where you should
 * parse the user config and discover/register accessories with Homebridge.
 */
export declare class ResideoPlatform implements DynamicPlatformPlugin {
    accessories: PlatformAccessory[];
    readonly api: API;
    readonly log: Logging;
    protected readonly hap: HAP;
    config: ResideoPlatformConfig;
    axios: AxiosInstance;
    sensorData: never[];
    private refreshInterval;
    locations?: locations;
    sensorAccessory: sensorAccessory;
    firmware: accessoryAttribute['softwareRevision'];
    platformConfig: ResideoPlatformConfig['options'];
    platformLogging: ResideoPlatformConfig['logging'];
    debugMode: boolean;
    version: string;
    action: string;
    constructor(log: Logging, config: ResideoPlatformConfig, api: API);
    /**
     * This function is invoked when homebridge restores cached accessories from disk at startup.
     * It should be used to setup event handlers for characteristics and update respective values.
     */
    configureAccessory(accessory: PlatformAccessory): void;
    /**
     * Verify the config passed to the plugin is valid
     */
    verifyConfig(): void;
    refreshAccessToken(): Promise<void>;
    /**
     * Exchange the refresh token for an access token
     */
    getAccessToken(): Promise<void>;
    /**
     * The refresh token will periodically change.
     * This method saves the updated refresh token in the config.json file
     * @param newRefreshToken
     */
    updateRefreshToken(newRefreshToken: string): Promise<void>;
    /**
     * this method discovers the Locations
     */
    discoverlocations(): Promise<any>;
    /**
     * this method discovers the rooms at each location
     */
    getCurrentSensorData(location: location, device: resideoDevice & devicesConfig, group: T9groups): Promise<any>;
    private normalizeSensorDate;
    /**
     * this method discovers the firmware Veriosn for T9 Thermostats
     */
    getSoftwareRevision(location: location, device: resideoDevice & devicesConfig): Promise<any>;
    /**
     * This method is used to discover the your location and devices.
     * Accessories are registered by either their DeviceClass, DeviceModel, or DeviceID
     */
    private discoverDevices;
    private deviceClass;
    private discoverRoomSensors;
    private roomsensordisplaymethod;
    private createThermostat;
    private createLeak;
    private createValve;
    private createRoomSensors;
    private createRoomSensorThermostat;
    private leaksensorFirmwareNewAccessory;
    private leaksensorFirmwareExistingAccessory;
    private valveFirmwareNewAccessory;
    private valveFirmwareExistingAccessory;
    private roomsensorFirmwareNewAccessory;
    private roomsensorFirmwareExistingAccessory;
    thermostatFirmwareNewAccessory(device: resideoDevice & devicesConfig, accessory: PlatformAccessory, location: any): Promise<void>;
    thermostatFirmwareExistingAccessory(device: resideoDevice & devicesConfig, existingAccessory: PlatformAccessory, location: any): Promise<void>;
    externalOrPlatform(device: resideoDevice & devicesConfig, accessory: PlatformAccessory): Promise<void>;
    externalAccessory(accessory: PlatformAccessory): Promise<void>;
    unregisterPlatformAccessories(existingAccessory: PlatformAccessory): void;
    apiError(e: any): void;
    statusCode(statusCode: number, action: string): Promise<void>;
    platformConfigOptions(): Promise<void>;
    platformLogs(): Promise<void>;
    getVersion(): Promise<void>;
    /**
     * If device level logging is turned on, log to log.warn
     * Otherwise send debug logs to log.debug
     */
    infoLog(...log: any[]): void;
    warnLog(...log: any[]): void;
    debugWarnLog(...log: any[]): void;
    errorLog(...log: any[]): void;
    debugErrorLog(...log: any[]): void;
    debugLog(...log: any[]): void;
    enablingPlatfromLogging(): boolean;
}
//# sourceMappingURL=platform.d.ts.map